@@ -4,16 +4,14 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef ABSTRACTREMOTEINPUT_H
-#define ABSTRACTREMOTEINPUT_H
+#pragma once
 
 #include <QLoggingCategory>
 #include <QObject>
 
+#include "plugin_mousepad_debug.h"
 #include <core/networkpacket.h>
 
-Q_DECLARE_LOGGING_CATEGORY(KDECONNECT_PLUGIN_MOUSEPAD)
-
 class AbstractRemoteInput : public QObject
 {
     Q_OBJECT
@@ -26,5 +24,3 @@ public:
         return false;
     };
 };
-
-#endif
